@@ -1,7 +1,7 @@
 package Screensaver::Any;
 
-our $DATE = '2019-09-03'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2019-09-04'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -373,6 +373,25 @@ sub disable_screensaver {
     [501, "Not yet implemented except for gnome-screensaver"];
 }
 
+$SPEC{screensaver_is_enabled} = {
+    v => 1.1,
+    summary => 'Check whether screensaver is enabled',
+    args => {
+        %arg_screensaver,
+    },
+};
+sub screensaver_is_enabled {
+    my %args = @_;
+    my $screensaver = $args{screensaver} // detect_screensaver();
+
+    if ($screensaver eq 'gnome') {
+        my $read = readpipe "gsettings", "get", "org.gnome.desktop.lockdown", "disable-lock-screen";
+        if ($?) { return [500, "Failed"] } else { return [200, "OK", $read =~ /false/ ? 1 : $read =~ /true/ ? 0 : undef] }
+    }
+
+    [501, "Not yet implemented except for gnome-screensaver"];
+}
+
 $SPEC{activate_screensaver} = {
     v => 1.1,
     summary => 'Activate screensaver immediately and lock screen',
@@ -568,7 +587,7 @@ Screensaver::Any - Common interface to screensaver/screenlocker functions
 
 =head1 VERSION
 
-This document describes version 0.005 of Screensaver::Any (from Perl distribution Screensaver-Any), released on 2019-09-03.
+This document describes version 0.006 of Screensaver::Any (from Perl distribution Screensaver-Any), released on 2019-09-04.
 
 =head1 DESCRIPTION
 
@@ -866,6 +885,41 @@ Return value:  (any)
 
 
 
+=head2 screensaver_is_enabled
+
+Usage:
+
+ screensaver_is_enabled(%args) -> [status, msg, payload, meta]
+
+Check whether screensaver is enabled.
+
+This function is not exported by default, but exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<screensaver> => I<str>
+
+Explicitly set screensaver program to use.
+
+The default, when left undef, is to detect what screensaver is running,
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
 =head2 set_screensaver_timeout
 
 Usage:
